# PARI/GP

To use this language, use the class "language-parigp".

## Comments

    \\ Single line comment
    /* Multi line
    comment */

## Strings

    ""
    "Foo \"bar\" baz"

## Numbers

    0.
    42
    3 . 14 15 9
    5.2 E +12
    .89

## Ignored whitespaces

    p r i n t ("hello")
    if err(1/i, E, print (E))
    a + = b \ / c

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Comment-like substrings

    "foo /* baz */" "foo \\ baz"